==> openjdk-src-13.0.2.u8-1-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_sw.java <==
/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_sw extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "KES", "Ksh" },
            { "THB", "\u0e3f" },
            { "TZS", "TSh" },
            { "aed", "Dirham ya Falme za Kiarabu" },
            { "afn", "Afghani ya Afghanistan" },
            { "all", "Lek ya Albania" },
            { "amd", "Dram ya Armenia" },
            { "ang", "Guilder ya Antili za Kiholanzi" },
            { "aoa", "Kwanza ya Angola" },
            { "ars", "Peso ya Argentina" },
            { "aud", "Dola ya Australia" },
            { "awg", "Florin ya Aruba" },
            { "azn", "Manat ya Azerbaijan" },
            { "bam", "Convertible Mark ya Bosnia na Hezegovina" },
            { "bbd", "Dola ya Barbados" },
            { "bdt", "Taka ya Bangladesh" },
            { "bgn", "Lev ya Bulgaria" },
            { "bhd", "Dinar ya Bahrain" },
            { "bif", "Faranga ya Burundi" },
            { "bmd", "Dola ya Bermuda" },
            { "bnd", "Dola ya Brunei" },
            { "bob", "Boliviano ya Bolivia" },
            { "brl", "Real ya Brazil" },
            { "bsd", "Dola ya Bahamas" },
            { "btn", "Ngultrum ya Bhutan" },
            { "bwp", "Pula ya Botswana" },
            { "byn", "Ruble ya Belarus" },
            { "byr", "Ruble ya Belarusi (2000\u20132016)" },
            { "bzd", "Dola ya Belize" },
            { "cad", "Dola ya Canada" },
            { "cdf", "Faranga ya Kongo" },
            { "chf", "Faranga ya Uswisi" },
            { "clp", "Peso ya Chile" },
            { "cnh", "Yuan ya Uchina (huru)" },
            { "cny", "Yuan ya Uchina" },
            { "cop", "Peso ya Colombia" },
            { "crc", "Colon ya Costa Rica" },
            { "cuc", "Peso ya Cuba Inayoweza Kubadilishwa" },
            { "cup", "Peso ya Cuba" },
            { "cve", "Eskudo ya Cape Verde" },
            { "czk", "CZK" },
            { "djf", "Faranga ya Djibouti" },
            { "dkk", "Krone ya Denmark" },
            { "dop", "Peso ya Dominica" },
            { "dzd", "Dinar ya Aljeria" },
            { "egp", "Pauni ya Misri" },
            { "ern", "Nakfa ya Eritrea" },
            { "etb", "Birr ya Uhabeshi" },
            { "eur", "Yuro" },
            { "fjd", "Dola ya Fiji" },
            { "fkp", "Pauni ya Visiwa vya Falkland" },
            { "gbp", "Pauni ya Uingereza" },
            { "gel", "Lari ya Georgia" },
            { "ghc", "Sedi ya Ghana" },
            { "ghs", "Cedi ya Ghana" },
            { "gip", "Pauni ya Gibraltar" },
            { "gmd", "Dalasi ya Gambia" },
            { "gnf", "Faranga ya Guinea" },
            { "gns", "Faranga ya Gine" },
            { "gtq", "Quetzal ya Guatemala" },
            { "gyd", "Dola ya Guyana" },
            { "hkd", "Dola ya Hong Kong" },
            { "hnl", "Lempira ya Hondurasi" },
            { "hrk", "Kuna ya Croatia" },
            { "htg", "Gourde ya Haiti" },
            { "huf", "Forint ya Hungaria" },
            { "idr", "Rupiah ya Indonesia" },
            { "ils", "Shekeli Mpya ya Israel" },
            { "inr", "Rupia ya India" },
            { "iqd", "Dinar ya Iraq" },
            { "irr", "Rial ya Iran" },
            { "isk", "Krona ya Aisilandi" },
            { "jmd", "Dola ya Jamaica" },
            { "jod", "Dinar ya Jordan" },
            { "jpy", "Yen ya Ujapani" },
            { "kes", "Shilingi ya Kenya" },
            { "kgs", "Som ya Kyrgystan" },
            { "khr", "Riel ya Cambodia" },
            { "kmf", "Faranga ya Comoros" },
            { "kpw", "Won ya Korea Kaskazini" },
            { "krw", "Won ya Korea Kusini" },
            { "kwd", "Dinar ya Kuwait" },
            { "kyd", "Dola ya Visiwa vya Cayman" },
            { "kzt", "Tenge ya Kazakhstan" },
            { "lak", "Kip ya Laosi" },
            { "lbp", "Pauni ya Lebanon" },
            { "lkr", "Rupia ya Sri Lanka" },
            { "lrd", "Dola ya Liberia" },
            { "lsl", "Loti ya Lesoto" },
            { "ltl", "Litas ya Lithuania" },
            { "lvl", "Lats ya Lativia" },
            { "lyd", "Dinari ya Libya" },
            { "mad", "Dirham ya Morocco" },
            { "mdl", "Leu ya Moldova" },
            { "mga", "Ariari ya Madagascar" },
            { "mkd", "Denar ya Macedonia" },
            { "mmk", "Kyat ya Myanmar" },
            { "mnt", "Tugrik ya Mongolia" },
            { "mop", "Pataca ya Macau" },
            { "mro", "Ouguiya ya Mauritania (1973\u20132017)" },
            { "mru", "Ouguiya ya Mauritania" },
            { "mur", "Rupia ya Mauritius" },
            { "mvr", "Rufiyaa ya Maldives" },
            { "mwk", "Kwacha ya Malawi" },
            { "mxn", "Peso ya Mexico" },
            { "myr", "Ringgit ya Malaysia" },
            { "mzm", "Metikali ya Msumbiji (1980\u20132006)" },
            { "mzn", "Metikali ya Msumbiji" },
            { "nad", "Dola ya Namibia" },
            { "ngn", "Naira ya Nigeria" },
            { "nio", "Cordoba ya Nicaragua" },
            { "nok", "Krone ya Norway" },
            { "npr", "Rupia ya Nepal" },
            { "nzd", "Dola ya New Zealand" },
            { "omr", "Rial ya Omani" },
            { "pab", "Balboa ya Panama" },
            { "pen", "Sol ya Peru" },
            { "pgk", "Kina ya Papua New Guinea" },
            { "php", "Peso ya Ufilipino" },
            { "pkr", "Rupia ya Pakistan" },
            { "pln", "Zloty ya Poland" },
            { "pyg", "Guarani ya Paraguay" },
            { "qar", "Rial ya Qatar" },
            { "ron", "Leu ya Romania" },
            { "rsd", "Dinar ya Serbia" },
            { "rub", "Ruble ya Urusi" },
            { "rwf", "Faranga ya Rwanda" },
            { "sar", "Riyal ya Saudia" },
            { "sbd", "Dola ya Visiwa vya Solomon" },
            { "scr", "Rupia ya Ushelisheli" },
            { "sdg", "Pauni ya Sudan" },
            { "sdp", "Pauni ya Sudani (1957\u20131998)" },
            { "sek", "Krona ya Uswidi" },
            { "sgd", "Dola ya Singapore" },
            { "shp", "Pauni ya St. Helena" },
            { "sll", "Leone" },
            { "sos", "Shilingi ya Somalia" },
            { "srd", "Dola ya Suriname" },
            { "ssp", "Pauni ya Sudan Kusini" },
            { "std", "Dobra ya Sao Tome na Principe (1977\u20132017)" },
            { "stn", "Dobra ya Sao Tome na Principe" },
            { "syp", "Pauni ya Syria" },
            { "szl", "Lilangeni" },
            { "thb", "Baht ya Tailandi" },
            { "tjs", "Somoni ya Tajikistan" },
            { "tmt", "Manat ya Turkmenistan" },
            { "tnd", "Dinari ya Tunisia" },
            { "top", "Pa\u02bbanga ya Tonga" },
            { "try", "Lira ya Uturuki" },
            { "ttd", "Dola ya Trinidad na Tobago" },
            { "twd", "Dola ya Taiwan" },
            { "tzs", "Shilingi ya Tanzania" },
            { "uah", "Hryvnia ya Ukraine" },
            { "ugx", "Shilingi ya Uganda" },
            { "usd", "Dola ya Marekani" },
            { "uyu", "Peso ya Uruguay" },
            { "uzs", "Som ya Uzbekistan" },
            { "vef", "Bolivar ya Venezuela (2008\u20132018)" },
            { "ves", "Bolivar ya Venezuela" },
            { "vnd", "Dong ya Vietnam" },
            { "vuv", "Vatu ya Vanuatu" },
            { "wst", "Tala ya Samoa" },
            { "xaf", "Faranga ya Afrika ya Kati CFA" },
            { "xcd", "Dola ya Caribbean Mashariki" },
            { "xof", "Faranga ya Afrika Magharibi CFA" },
            { "xpf", "Faranga ya CFP" },
            { "xxx", "Sarafu isiyojulikana" },
            { "yer", "Rial ya Yemen" },
            { "zar", "Randi ya Afrika Kusini" },
            { "zmk", "Kwacha ya Zambia (1968\u20132012)" },
            { "zmw", "Kwacha ya Zambia" },
            { "zwd", "Dola ya Zimbabwe" },
        };
        return data;
    }
}

==> openjdk-src-14.0.2.u12-1-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_sw.java <==
/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_sw extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_CZK = "CZK";
        final Object[][] data = new Object[][] {
            { "mwk", "Kwacha ya Malawi" },
            { "FJD", "FJD" },
            { "STD", "STD" },
            { "LVL", "LVL" },
            { "SCR", "SCR" },
            { "CDF", "CDF" },
            { "BBD", "BBD" },
            { "mga", "Ariari ya Madagascar" },
            { "HNL", "HNL" },
            { "UGX", "UGX" },
            { "ZAR", "ZAR" },
            { "STN", "STN" },
            { "bam", "Convertible Mark ya Bosnia na Hezegovina" },
            { "egp", "Pauni ya Misri" },
            { "CUC", "CUC" },
            { "ssp", "Pauni ya Sudan Kusini" },
            { "BSD", "BSD" },
            { "nio", "Cordoba ya Nicaragua" },
            { "SDG", "SDG" },
            { "nzd", "Dola ya New Zealand" },
            { "IQD", "IQD" },
            { "brl", "Real ya Brazil" },
            { "CUP", "CUP" },
            { "GMD", "GMD" },
            { "fjd", "Dola ya Fiji" },
            { "RSD", "RSD" },
            { "mxn", "Peso ya Mexico" },
            { "std", "Dobra ya Sao Tome na Principe (1977\u20132017)" },
            { "lvl", "Lats ya Lativia" },
            { "scr", "Rupia ya Ushelisheli" },
            { "cdf", "Faranga ya Kongo" },
            { "bbd", "Dola ya Barbados" },
            { "MYR", "MYR" },
            { "hnl", "Lempira ya Hondurasi" },
            { "ugx", "Shilingi ya Uganda" },
            { "FKP", "FKP" },
            { "zar", "Randi ya Afrika Kusini" },
            { "stn", "Dobra ya Sao Tome na Principe" },
            { "UYU", "UYU" },
            { "cuc", "Peso ya Cuba Inayoweza Kubadilishwa" },
            { "bsd", "Dola ya Bahamas" },
            { "CVE", "CVE" },
            { "OMR", "OMR" },
            { "sdg", "Pauni ya Sudan" },
            { "KES", "Ksh" },
            { "SEK", "SEK" },
            { "BTN", "BTN" },
            { "iqd", "Dinar ya Iraq" },
            { "GNF", "GNF" },
            { "sdp", "Pauni ya Sudani (1957\u20131998)" },
            { "cup", "Peso ya Cuba" },
            { "gmd", "Dalasi ya Gambia" },
            { "MZN", "MZN" },
            { "twd", "Dola ya Taiwan" },
            { "ARS", "ARS" },
            { "rsd", "Dinar ya Serbia" },
            { "QAR", "QAR" },
            { "myr", "Ringgit ya Malaysia" },
            { "IRR", "IRR" },
            { "fkp", "Pauni ya Visiwa vya Falkland" },
            { "xof", "Faranga ya Afrika Magharibi CFA" },
            { "THB", "\u0e3f" },
            { "UZS", "UZS" },
            { "uyu", "Peso ya Uruguay" },
            { "BDT", "BDT" },
            { "cve", "Eskudo ya Cape Verde" },
            { "omr", "Rial ya Omani" },
            { "LYD", "LYD" },
            { "kes", "Shilingi ya Kenya" },
            { "sek", "Krona ya Uswidi" },
            { "KWD", "KWD" },
            { "btn", "Ngultrum ya Bhutan" },
            { "RUB", "RUB" },
            { "gnf", "Faranga ya Guinea" },
            { "ISK", "ISK" },
            { "mzn", "Metikali ya Msumbiji" },
            { "mzm", "Metikali ya Msumbiji (1980\u20132006)" },
            { "ars", "Peso ya Argentina" },
            { "qar", "Rial ya Qatar" },
            { "MKD", "MKD" },
            { "irr", "Rial ya Iran" },
            { "gns", "Faranga ya Gine" },
            { "DZD", "DZD" },
            { "thb", "Baht ya Tailandi" },
            { "uzs", "Som ya Uzbekistan" },
            { "xpf", "Faranga ya CFP" },
            { "PAB", "PAB" },
            { "SGD", "SGD" },
            { "bdt", "Taka ya Bangladesh" },
            { "KGS", "KGS" },
            { "lyd", "Dinari ya Libya" },
            { "kwd", "Dinar ya Kuwait" },
            { "rub", "Ruble ya Urusi" },
            { "CHF", "CHF" },
            { "HRK", "HRK" },
            { "isk", "Krona ya Aisilandi" },
            { "DJF", "DJF" },
            { "mkd", "Denar ya Macedonia" },
            { "TZS", "TSh" },
            { "dzd", "Dinar ya Aljeria" },
            { "pab", "Balboa ya Panama" },
            { "sgd", "Dola ya Singapore" },
            { "KHR", "KHR" },
            { "IDR", "IDR" },
            { "kgs", "Som ya Kyrgystan" },
            { "KYD", "KYD" },
            { "BWP", "BWP" },
            { "SHP", "SHP" },
            { "TJS", "TJS" },
            { "xaf", "Faranga ya Afrika ya Kati CFA" },
            { "AED", "AED" },
            { "RWF", "RWF" },
            { "chf", "Faranga ya Uswisi" },
            { "hrk", "Kuna ya Croatia" },
            { "djf", "Faranga ya Djibouti" },
            { "DKK", "DKK" },
            { "BGN", "BGN" },
            { "MMK", "MMK" },
            { "NOK", "NOK" },
            { "SYP", "SYP" },
            { "tzs", "Shilingi ya Tanzania" },
            { "vnd", "Dong ya Vietnam" },
            { "aud", "Dola ya Australia" },
            { "LKR", "LKR" },
            { "khr", "Riel ya Cambodia" },
            { "CZK", metaValue_CZK },
            { "idr", "Rupiah ya Indonesia" },
            { "kyd", "Dola ya Visiwa vya Cayman" },
            { "HTG", "HTG" },
            { "bwp", "Pula ya Botswana" },
            { "shp", "Pauni ya St. Helena" },
            { "tjs", "Somoni ya Tajikistan" },
            { "BHD", "BHD" },
            { "rwf", "Faranga ya Rwanda" },
            { "aed", "Dirham ya Falme za Kiarabu" },
            { "KZT", "KZT" },
            { "SZL", "SZL" },
            { "dkk", "Krone ya Denmark" },
            { "zwd", "Dola ya Zimbabwe" },
            { "YER", "YER" },
            { "bgn", "Lev ya Bulgaria" },
            { "AFN", "AFN" },
            { "mmk", "Kyat ya Myanmar" },
            { "nok", "Krone ya Norway" },
            { "syp", "Pauni ya Syria" },
            { "AWG", "AWG" },
            { "NPR", "NPR" },
            { "MNT", "MNT" },
            { "lkr", "Rupia ya Sri Lanka" },
            { "czk", metaValue_CZK },
            { "BYN", "BYN" },
            { "HUF", "HUF" },
            { "xcd", "Dola ya Caribbean Mashariki" },
            { "BYR", "BYR" },
            { "htg", "Gourde ya Haiti" },
            { "BIF", "BIF" },
            { "bhd", "Dinar ya Bahrain" },
            { "kzt", "Tenge ya Kazakhstan" },
            { "szl", "Lilangeni" },
            { "yer", "Rial ya Yemen" },
            { "afn", "Afghani ya Afghanistan" },
            { "BZD", "BZD" },
            { "MOP", "MOP" },
            { "NAD", "NAD" },
            { "awg", "Florin ya Aruba" },
            { "npr", "Rupia ya Nepal" },
            { "mnt", "Tugrik ya Mongolia" },
            { "gbp", "Pauni ya Uingereza" },
            { "byn", "Ruble ya Belarus" },
            { "PEN", "PEN" },
            { "huf", "Forint ya Hungaria" },
            { "WST", "WST" },
            { "TMT", "TMT" },
            { "byr", "Ruble ya Belarusi (2000\u20132016)" },
            { "bif", "Faranga ya Burundi" },
            { "GTQ", "GTQ" },
            { "CLP", "CLP" },
            { "TND", "TND" },
            { "bzd", "Dola ya Belize" },
            { "mop", "Pataca ya Macau" },
            { "nad", "Dola ya Namibia" },
            { "SLL", "SLL" },
            { "pen", "Sol ya Peru" },
            { "wst", "Tala ya Samoa" },
            { "tmt", "Manat ya Turkmenistan" },
            { "DOP", "DOP" },
            { "KMF", "KMF" },
            { "gtq", "Quetzal ya Guatemala" },
            { "clp", "Peso ya Chile" },
            { "tnd", "Dinari ya Tunisia" },
            { "GEL", "GEL" },
            { "MAD", "MAD" },
            { "sll", "Leone" },
            { "TOP", "TOP" },
            { "AZN", "AZN" },
            { "PGK", "PGK" },
            { "CNH", "CNH" },
            { "UAH", "UAH" },
            { "ERN", "ERN" },
            { "dop", "Peso ya Dominica" },
            { "kmf", "Faranga ya Comoros" },
            { "MRO", "MRO" },
            { "gel", "Lari ya Georgia" },
            { "MRU", "MRU" },
            { "mad", "Dirham ya Morocco" },
            { "azn", "Manat ya Azerbaijan" },
            { "top", "Pa\u02bbanga ya Tonga" },
            { "pgk", "Kina ya Papua New Guinea" },
            { "BMD", "BMD" },
            { "PHP", "PHP" },
            { "cnh", "Yuan ya Uchina (huru)" },
            { "uah", "Hryvnia ya Ukraine" },
            { "PYG", "PYG" },
            { "JMD", "JMD" },
            { "ern", "Nakfa ya Eritrea" },
            { "COP", "COP" },
            { "mro", "Ouguiya ya Mauritania (1973\u20132017)" },
            { "cny", "Yuan ya Uchina" },
            { "mru", "Ouguiya ya Mauritania" },
            { "ETB", "ETB" },
            { "SOS", "SOS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "LAK", "LAK" },
            { "bmd", "Dola ya Bermuda" },
            { "BND", "BND" },
            { "php", "Peso ya Ufilipino" },
            { "xxx", "Sarafu isiyojulikana" },
            { "LRD", "LRD" },
            { "pyg", "Guarani ya Paraguay" },
            { "jmd", "Dola ya Jamaica" },
            { "ALL", "ALL" },
            { "VES", "VES" },
            { "ZMW", "ZMW" },
            { "cop", "Peso ya Colombia" },
            { "usd", "Dola ya Marekani" },
            { "etb", "Birr ya Uhabeshi" },
            { "GHS", "GHS" },
            { "GYD", "GYD" },
            { "KPW", "KPW" },
            { "BOB", "BOB" },
            { "MDL", "MDL" },
            { "sos", "Shilingi ya Somalia" },
            { "vef", "Bolivar ya Venezuela (2008\u20132018)" },
            { "vuv", "Vatu ya Vanuatu" },
            { "lak", "Kip ya Laosi" },
            { "AMD", "AMD" },
            { "bnd", "Dola ya Brunei" },
            { "zmk", "Kwacha ya Zambia (1968\u20132012)" },
            { "TRY", "TRY" },
            { "LBP", "LBP" },
            { "JOD", "JOD" },
            { "lrd", "Dola ya Liberia" },
            { "all", "Lek ya Albania" },
            { "ghc", "Sedi ya Ghana" },
            { "ves", "Bolivar ya Venezuela" },
            { "zmw", "Kwacha ya Zambia" },
            { "MUR", "MUR" },
            { "GIP", "GIP" },
            { "RON", "RON" },
            { "ils", "Shekeli Mpya ya Israel" },
            { "ghs", "Cedi ya Ghana" },
            { "gyd", "Dola ya Guyana" },
            { "kpw", "Won ya Korea Kaskazini" },
            { "NGN", "NGN" },
            { "bob", "Boliviano ya Bolivia" },
            { "mdl", "Leu ya Moldova" },
            { "CRC", "CRC" },
            { "PKR", "PKR" },
            { "amd", "Dram ya Armenia" },
            { "ANG", "ANG" },
            { "try", "Lira ya Uturuki" },
            { "lbp", "Pauni ya Lebanon" },
            { "jod", "Dinar ya Jordan" },
            { "hkd", "Dola ya Hong Kong" },
            { "eur", "Yuro" },
            { "SRD", "SRD" },
            { "lsl", "Loti ya Lesoto" },
            { "LTL", "LTL" },
            { "SAR", "SAR" },
            { "TTD", "TTD" },
            { "cad", "Dola ya Canada" },
            { "MVR", "MVR" },
            { "mur", "Rupia ya Mauritius" },
            { "gip", "Pauni ya Gibraltar" },
            { "ron", "Leu ya Romania" },
            { "AOA", "AOA" },
            { "PLN", "PLN" },
            { "SBD", "SBD" },
            { "ngn", "Naira ya Nigeria" },
            { "crc", "Colon ya Costa Rica" },
            { "pkr", "Rupia ya Pakistan" },
            { "ang", "Guilder ya Antili za Kiholanzi" },
            { "MWK", "MWK" },
            { "srd", "Dola ya Suriname" },
            { "ltl", "Litas ya Lithuania" },
            { "sar", "Riyal ya Saudia" },
            { "ttd", "Dola ya Trinidad na Tobago" },
            { "MGA", "MGA" },
            { "mvr", "Rufiyaa ya Maldives" },
            { "inr", "Rupia ya India" },
            { "BAM", "BAM" },
            { "EGP", "EGP" },
            { "SSP", "SSP" },
            { "krw", "Won ya Korea Kusini" },
            { "aoa", "Kwanza ya Angola" },
            { "jpy", "Yen ya Ujapani" },
            { "pln", "Zloty ya Poland" },
            { "sbd", "Dola ya Visiwa vya Solomon" },
            { "NIO", "NIO" },
        };
        return data;
    }
}
